ledger.MovementsByProject (Movements) — amici1

# `ledger.MovementsByProject` (Movements)

Actions

Filter parameters

- `<django.db.models.fields.related.ForeignKey: year>`

- `<lino.core.choicelists.ChoiceListField: journal_group>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.fields.DummyField object at 0x7fc81dfdcf98>`

- `<django.db.models.fields.related.ForeignKey: account>`

- `<django.db.models.fields.related.ForeignKey: journal>`

- `<lino.core.choicelists.ChoiceListField: cleared>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: start_period>`

- `<django.db.models.fields.related.ForeignKey: end_period>`

## Filter parameters